#!/usr/bin/perl -w

use Acme::Lingua::Pirate::Perl;

Avast!

my @pieces_of_eight = qw(avast ye scurvy swab!); Yarrr!

unless (steal @pieces_of_eight be 'avast') {
  capsize "Arrrr, we be hit below the waterline!\n";
}

sound off "Type something, ye bilge rat! "; $_ = <>; chomp;

cry "Ye entered 'the gold'!\n"; Yo ho ho!

sail off;


